'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = format;

/**
 * Get formatted commit message
 * @param  {object}  input object containing structured results
 * @param  {boolean} debug show debug information in commit message
 * @return {string}        formatted debug message
 */

function format(input, debug = false) {
	const results = debug ? (0, _lodash.toPairs)(input).reduce((registry, item) => {
		var _item = (0, _slicedToArray3.default)(item, 2);

		const name = _item[0],
		      value = _item[1];

		registry[name] = value === null ? _chalk2.default.grey(`<${name}>`) : _chalk2.default.bold(value);
		return registry;
	}, {}) : input;

	// Return formatted string
	const type = results.type,
	      scope = results.scope,
	      subject = results.subject,
	      body = results.body,
	      footer = results.footer;

	return [`${type}${scope ? '(' : ''}${scope}${scope ? ')' : ''}${type || scope ? ':' : ''} ${subject}`, body, footer].filter(Boolean).join('\n');
}
module.exports = exports['default'];
//# sourceMappingURL=format.js.map