'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

exports.default = getForcedCaseFn;

var _lodash = require('lodash');

var _ = _interopRequireWildcard(_lodash);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Get forced case for rule
 * @param {object} rule to parse
 * @return {fn} transform function applying the enforced case
 */
function getForcedCaseFn(rule) {
	const noop = input => input;

	if (!rule) {
		return noop;
	}

	var _rule = (0, _slicedToArray3.default)(rule, 1);

	const config = _rule[0];


	if (!Array.isArray(config)) {
		return noop;
	}

	var _config = (0, _slicedToArray3.default)(config, 1);

	const level = _config[0];


	if (level === 0) {
		return;
	}

	var _config2 = (0, _slicedToArray3.default)(config, 2);

	const when = _config2[1];


	if (when === 'neve') {
		return;
	}

	var _config3 = (0, _slicedToArray3.default)(config, 3);

	const target = _config3[2];


	if (Array.isArray(target)) {
		return noop;
	}

	switch (target) {
		case 'camel-case':
			return input => _.camelCase(input);
		case 'kebab-case':
			return input => _.kebabCase(input);
		case 'snake-case':
			return input => _.snakeCase(input);
		case 'pascal-case':
			return input => _.upperFirst(_.camelCase(input));
		case 'start-case':
			return input => _.startCase(input);
		case 'upper-case':
		case 'uppercase':
			return input => input.toUpperCase();
		case 'sentence-case':
		case 'sentencecase':
			return input => `${input.charAt(0).toUpperCase()}${input.substring(1).toLowerCase()}`;
		case 'lower-case':
		case 'lowercase':
		case 'lowerCase':
			// Backwards compat config-angular v4
			return input => input.toLowerCase() === input;
		default:
			throw new TypeError(`Unknown target case "${rule[2]}"`);
	}
}
module.exports = exports['default'];
//# sourceMappingURL=get-forced-case-fn.js.map