'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

exports.default = getForcedLeadingFn;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Get forced leading for rule
 * @param {object} rule to parse
 * @return {fn} transform function applying the leading
 */
function getForcedLeadingFn(rule) {
	const noop = input => input;
	const remove = input => {
		const fragments = input.split('\n');
		return fragments[0] === '' ? fragments.slice(1).join('\n') : input;
	};
	const lead = input => {
		const fragments = input.split('\n');
		return fragments[0] === '' ? input : ['', ...fragments].join('\n');
	};

	if (!rule) {
		return noop;
	}

	const leading = getForcedLeading(rule);

	if (leading === null) {
		return noop;
	}

	return leading ? lead : remove;
}

/**
 * Get forced leading for rule
 * @param {object} rule to parse
 * @return {boolean|null} transform function applying the leading
 */
function getForcedLeading(rule) {
	if (!rule) {
		return null;
	}

	var _rule = (0, _slicedToArray3.default)(rule, 2),
	    _rule$ = (0, _slicedToArray3.default)(_rule[1], 2);

	const severity = _rule$[0],
	      applicable = _rule$[1];

	const negated = applicable === 'never';

	if (severity === 0) {
		return null;
	}

	return !negated;
}
module.exports = exports['default'];
//# sourceMappingURL=get-forced-leading-fn.js.map